=======
Credits
=======

Development Lead
----------------

* `Etienne Lac <https://gitlab.com/etienne.lac>`_ <etienne.lac@safrangroup.com>
* `Duc Trung Le <https://gitlab.com/ductrungle>`_ <duc-trung.le@safrangroup.com>

Contributors
------------

* `Frederic Collonval <https://gitlab.com/fcollonval>`_
* `Adrien Delsalle <https://gitlab.com/adriendelsalle>`_
* `Guy De Spiegeleer <https://gitlab.com/GuyDS>`_ <guy.de-spiegeleer@safrangroup.com>
* Alexis Cassier <alexis.cassier@safrangroup.com>
* Amath Waly Ndiaye
* Thomas Federici <thomas.federici@safrangroup.com>
* `Jeffrey Borlik <https://gitlab.com/JeffreyBorlik>`_
* `Adrien Talatizi <https://gitlab.com/AdrienTalatizi>`_
